==> gamlss.inf_1.0-1.tar.gz: gamlss.inf/man/sda.Rd <==
\name{sda}
\alias{sda}
\docType{data}
\title{Data for using for simulation}
\description{
Those data values are used to create simaulated data
}
\usage{data("sda")}
\format{
  A data frame with 120 observations on the following 5 variables.
  \describe{
    \item{\code{x}}{the explanatory variable}
    \item{\code{mu}}{the fitted mu}
    \item{\code{sigma}}{the fitted sigma}
    \item{\code{nu}}{the fitted nu}
    \item{\code{tau}}{the fitted tau}
  }
}

\source{The data are fitted values of model}
\references{
Rigby, R. A. and  Stasinopoulos D. M. (2005). Generalized additive models for location, scale and shape,(with discussion), 
\emph{Appl. Statist.}, \bold{54}, part 3, pp 507-554.

Stasinopoulos D. M., Rigby R.A. and Akantziliotou C. (2006) Instructions on how to use the GAMLSS package in R.
Accompanying documentation in the current GAMLSS  help files, (see also  \url{http://www.gamlss.org/}).

Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R.
\emph{Journal of Statistical Software}, Vol. \bold{23}, Issue 7, Dec 2007, \url{http://www.jstatsoft.org/v23/i07}.

Stasinopoulos D. M., Rigby R.A., Heller G., Voudouris V., and De Bastiani F., (2017)
\emph{Flexible Regression and Smoothing: Using GAMLSS in R},  Chapman and Hall/CRC. 
\url{https://www.crcpress.com/Flexible-Regression-and-Smoothing-Using-GAMLSS-in-R/Stasinopoulos-Rigby-Heller-Voudouris-Bastiani/p/book/9781138197909}.
}
\examples{
data(sda)
fmu <- splinefun(sda$x, sda$mu)
curve(fmu, -2,2)
fsigma <- splinefun(sda$x, sda$sigma)
curve(fsigma, -2,2)
fnu <- splinefun(sda$x, sda$nu)
curve(fnu, -2,2)
ftau <- splinefun(sda$x, sda$tau)
curve(ftau, -2,2)
}
\keyword{datasets}

==> gamlss.inf_1.0-2.tar.gz: gamlss.inf/man/sda.Rd <==
\name{sda}
\alias{sda}
\docType{data}
\title{Data for using for simulation}
\description{
Those data values are used to create simaulated data
}
\usage{data("sda")}
\format{
  A data frame with 120 observations on the following 5 variables.
  \describe{
    \item{\code{x}}{the explanatory variable}
    \item{\code{mu}}{the fitted mu}
    \item{\code{sigma}}{the fitted sigma}
    \item{\code{nu}}{the fitted nu}
    \item{\code{tau}}{the fitted tau}
  }
}

\source{The data are fitted values of model}
\references{
Rigby, R. A. and  Stasinopoulos D. M. (2005). Generalized additive models for location, scale and shape,(with discussion), 
\emph{Appl. Statist.}, \bold{54}, part 3, pp 507-554.

Stasinopoulos D. M., Rigby R.A. and Akantziliotou C. (2006) Instructions on how to use the GAMLSS package in R.
Accompanying documentation in the current GAMLSS  help files, (see also  \url{https://www.gamlss.com/}).

Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R.
\emph{Journal of Statistical Software}, Vol. \bold{23}, Issue 7, Dec 2007, \url{https://www.jstatsoft.org/v23/i07}.

Stasinopoulos D. M., Rigby R.A., Heller G., Voudouris V., and De Bastiani F., (2017)
\emph{Flexible Regression and Smoothing: Using GAMLSS in R},  Chapman and Hall/CRC. 
\url{https://www.routledge.com/Flexible-Regression-and-Smoothing-Using-GAMLSS-in-R/Stasinopoulos-Rigby-Heller-Voudouris-Bastiani/p/book/9781138197909}.
}
\examples{
data(sda)
fmu <- splinefun(sda$x, sda$mu)
curve(fmu, -2,2)
fsigma <- splinefun(sda$x, sda$sigma)
curve(fsigma, -2,2)
fnu <- splinefun(sda$x, sda$nu)
curve(fnu, -2,2)
ftau <- splinefun(sda$x, sda$tau)
curve(ftau, -2,2)
}
\keyword{datasets}
